Module: GeneratorLabs
- Defined in:
- lib/generatorlabs.rb,
lib/generatorlabs/rbl.rb,
lib/generatorlabs/cert.rb,
lib/generatorlabs/client.rb,
lib/generatorlabs/config.rb,
lib/generatorlabs/contact.rb,
lib/generatorlabs/version.rb,
lib/generatorlabs/webhook.rb,
lib/generatorlabs/response.rb,
lib/generatorlabs/rate_limit_info.rb,
lib/generatorlabs/request_handler.rb
Overview
This file is part of the Generator Labs Ruby SDK package.
© Generator Labs <support@generatorlabs.com>
For the full copyright and license information, please view the LICENSE file that was distributed with this source code.
Defined Under Namespace
Classes: Cert, CertErrors, CertMonitors, CertProfiles, Client, Config, Contact, Contacts, Error, Groups, RBL, RBLCheck, RBLHosts, RBLProfiles, RBLSources, RateLimitInfo, RequestHandler, Response, Webhook
Constant Summary collapse
- VERSION =
Current version of the SDK
'2.0.0'